@@ -6,15 +6,15 @@ pub fn encode(set: &Vec<Vec<u8>>) -> Vec<u8> {
         
         let len: usize = x.len();
 
-        let mut len_buf: Vec<u8> = len.to_be_bytes().to_vec();
+        let mut len_buf: Vec<u8> = len.to_le_bytes().to_vec();
 
-        while len_buf[0] == 0 && len_buf.len() > 1 {
-            len_buf.remove(0);
+        while len_buf[len_buf.len() - 1] == 0 {
+            len_buf.remove(len_buf.len() - 1);
         }
 
-        let len_size: Vec<u8> = vec![0_u8; len_buf.len()];
+        len_buf.push(0);
 
-        [len_size, len_buf, x.to_vec()].concat()
+        [len_buf, x.to_vec()].concat()
 
     })
     .fold(vec![], |acc, x| [acc,x].concat())
@@ -31,31 +31,37 @@ pub fn decode(astro: &Vec<u8>) -> Vec<Vec<u8>> {
 
     while i < astro.len() {
 
-        let mut len_buf_size: usize = 0;
+        let mut len_buf: Vec<u8> = Vec::new();
 
-        while astro[i] == 0 {
+        while astro[i] != 0 {
             
-            len_buf_size += 1;
+            len_buf.push(astro[i]);
 
             i += 1
 
         }
 
-        let mut len_buf: Vec<u8> = astro[i..(i+len_buf_size)].to_vec();
+        i += 1;
 
-        while len_buf.len() < usize_bytes {
-            len_buf = [vec![0], len_buf].concat()
-        }
+        if len_buf.len() > usize_bytes {
 
-        i += len_buf_size;
+            break
+
+        } else {
         
-        let len: usize = usize::from_be_bytes(len_buf.try_into().unwrap());
+            while len_buf.len() < usize_bytes {
+                len_buf.push(0);
+            }
+            
+            let len: usize = usize::from_le_bytes(len_buf.try_into().unwrap());
 
-        let buf: Vec<u8> = astro[i..(i+len)].to_vec();
+            let buf: Vec<u8> = astro[i..(i + len)].to_vec();
 
-        i += len;
+            i += len;
 
-        set.push(buf)
+            set.push(buf)
+
+        }
 
     }
 
